@@ -3,15 +3,16 @@
 
 scratchFlag=""
 while [[ "$#" -gt 0 ]]; do
-  case $1 in
-    '-p'|'--force-pull') shift 0;;
-    '-n'|'--nobuild') exit 0; shift 0;;
-    '-s'|'--scratch') scratchFlag="--scratch"; shift 0;;
-  esac
-  shift 1
+	case $1 in
+		'-p'|'--force-pull') shift 0;;
+		'-n'|'--nobuild') exit 0; shift 0;;
+		'-s'|'--scratch') scratchFlag="--scratch"; shift 0;;
+	esac
+	shift 1
 done
 
-echo "[INFO] Trigger container-build in current branch: rhpkg container-build ${scratchFlag}"
+echo "[INFO] #0 Trigger container-build in current branch: rhpkg container-build ${scratchFlag}"
+git status || true
 tmpfile=$(mktemp) && rhpkg container-build ${scratchFlag} --nowait | tee 2>&1 $tmpfile
 taskID=$(cat $tmpfile | grep "Created task:" | sed -e "s#Created task:##") && brew watch-logs $taskID | tee 2>&1 $tmpfile
 ERRORS="$(grep "image build failed" $tmpfile)" && rm -f $tmpfile
